import os
import sys
blank = [chr(183)]  ##此处为空格格式;Windows控制台下可改为chr(12288) ;linux系统中可改为chr(32)【chr(32)==' ' ;chr(183)=='·' ;chr(12288)=='　'】
tabs = ['']
def DepthTraversal(nowDir, p):
    # 根据目录建立列表
    baseName = os.path.basename(nowDir)
    c = [baseName]
    p.append(c)

    ls = os.listdir(nowDir)
    for each in ls:
        nextPath = nowDir + os.sep + each
        nextPath_basename = os.path.basename(nextPath)
        if os.path.isdir(nextPath):
            DepthTraversal(nextPath, c)
        else:
            nextPath_basename = os.path.basename(nextPath)
            p.append(nextPath_basename)
def tree(lst):
    # 树状图输出列表
    l = len(lst)
    if l == 0:
        print('─' * 3)
    else:
        for i, j in enumerate(lst):
            if i != 0:
                #f.write(tabs[0])
                print(tabs[0], end='')
            if l == 1:
                s = '─' * 3
            elif i == 0:
                s = '┬' + '─' * 2
            elif i + 1 == l:
                s = '└' + '─' * 2
            else:
                s = '├' + '─' * 2
            #f.write(s)
            print(s, end='')
            if isinstance(j, list) or isinstance(j, tuple):
                if i + 1 == l:
                    tabs[0] += blank[0] * 3
                else:
                    tabs[0] += '│' + blank[0] * 2
                tree(j)
            else:
                print(j)
                #f.write(j + "\n")
    tabs[0] = tabs[0][:-3]

def main(args = None):
    if len(sys.argv) <=1:
        paths ='.'
    else:
        paths = sys.argv[1]
    try:
        path = os.path.abspath(paths)
    except IndexError:
        print("please input absolute path. bye bye.")
        exit()
    #f = open("out", 'w')
    TreeList = []
    DepthTraversal(path, TreeList)
    tree(TreeList)

if __name__ == '__main__':
    main()


import sys
import os
import re

def replace(file_name, output_file_name):
    try:
        pattern1 = r"\$\$\n*([\s\S]*?)\n*\$\$"
        new_pattern1 = r'\n<img src="https://www.zhihu.com/equation?tex=\1" alt="\1" class="ee_img tr_noresize" eeimg="1">\n'
        pattern2 = r"\$\n*(.*?)\n*\$"
        #new_pattern2 =r'\n<img src="https://www.zhihu.com/equation?tex=\1" alt="\1" class="ee_img tr_noresize" eeimg="1">\n'
        new_pattern2 =r'<img src="https://www.zhihu.com/equation?tex=\1" alt="\1" class="ee_img tr_noresize" eeimg="1">'
        f = open(file_name, 'r')
        f_output = open(output_file_name, 'w')
        all_lines = f.read()
        new_lines1 = re.sub(pattern1, new_pattern1, all_lines)
        new_lines2 = re.sub(pattern2, new_pattern2, new_lines1)
        f_output.write(new_lines2)
        f.close()
        f_output.close()
        print('{}->{}'.format(file_name,output_file_name))
    except ( e):
        print(e)

def dealFile(inputFile,outputFile='../'):
    input_dir = os.path.dirname(inputFile)
    input_name = os.path.basename(inputFile)
    input_name_noext = input_name.split('.')[0]
    if os.path.isdir(outputFile):
        output_dir = outputFile
        output_name = os.path.join(output_dir,input_name_noext+'_zhihu.md')
    else:
        output_dir= os.path.dirname(outputFile)
        output_name = outputFile
    return (inputFile,output_name)
def main(args=None):
    if args is None:
        args = sys.argv[1:]
    if len(sys.argv) < 2:
        print("usage: md2zhihu sourceFileName destineFileName.")
        sys.exit(1)
    if len(sys.argv) < 3:
        tempDistine = "./"
    else:
        tempDistine = sys.argv[2]
    paras = dealFile(sys.argv[1],tempDistine)
    #print(paras)
    replace(*paras)

if __name__ == "__main__":
    main()